# Release Notes

* [Version 1.5](./history/1.5.html)
* [Version 1.4](./history/1.4.html)
* [Version 1.3](./history/1.3.html)
* [Version 1.2](./history/1.2.html)
* [Version 1.1](./history/1.1.html)
* [Version 1.0](./history/1.0.html)
* [Pre Version 1.0](./history/pre1.0.html)
